@@ -16,6 +16,35 @@ sub from_plack3 :Path('/msg') :ActionClass('FromPSGI') {
    A::App3->new(msg => 'yolo')->to_psgi_app
 }
 
+sub from_plack_deferred :Path('/deferred') :ActionClass('FromPSGI') {
+   sub {
+      my ($env) = @_;
+      return sub {
+         my $responder = shift;
+         $responder->([ 200, ['Content-type' => 'text/plain'], ['Hello from a deferred response']]);
+      }
+   }
+}
+
+sub from_plack_stream :Path('/stream') :ActionClass('FromPSGI') {
+   my $app = sub {
+      my $env = shift;
+
+      return sub {
+         my $responder = shift;
+         my $writer = $responder->(
+            [ 200, [ 'Content-Type', 'application/json' ]]);
+
+         $writer->write('/');
+         $writer->write('w');
+         $writer->write('o');
+         $writer->write('o');
+         $writer->write('!');
+         $writer->close;
+      }
+   }
+}
+
 1;
 
 BEGIN {
